==> babel-preset-all-0.0.1.tgz: package/index.js <==

interopRequire = function (name) {
  const req = require(name)
  return name['default'] ? name['default'] : name
}

// export the config
module.exports = {
  presets: [
    interopRequire('babel-preset-es2015')  // enable all es2015 features
  , interopRequire('babel-preset-stage-0') // enable experimental (es2016, es2017) features
  , interopRequire('babel-preset-react')   // enable jsx and flowtype
  ]
, plugins: [
    // add legacy decorator support
    interopRequire('babel-plugin-transform-decorators-legacy')

    // turn on strict mode
  , interopRequire('babel-plugin-transform-strict-mode')

    // transform runtime
  , interopRequire('babel-plugin-transform-runtime')
  ]
, env: {
    development: {
      plugins: [
        // enable simple typechecking
        interopRequire('babel-plugin-typecheck')
      , [
          interopRequire('babel-plugin-react-transform')
        , {
            transforms: [{
              transform: "react-transform-hmr"
            , imports:   [ "react" ]
            , locals:    [ "module" ]
          }]
        }]
      ]
    }
  , production: {
      plugins: [
        // turn boolean literals into !0 for true and !1 for false.
        interopRequire('babel-plugin-transform-minify-booleans')

        // ensure that reserved words are quoted in property accesses
        // eg. obj.catch -> obj['catch']
      , interopRequire('babel-plugin-transform-es3-member-expression-literals')
      , interopRequire('babel-plugin-transform-es3-property-literals')

        // turn valid member expression property literals into plain identifiers
        // eg. obj['foo'] -> obj.foo
      , interopRequire('babel-plugin-transform-member-expression-literals')
      , interopRequire('babel-plugin-transform-property-literals')


        // remove debugger statements
      , interopRequire('babel-plugin-transform-remove-debugger')

        // convert === and !== to == and != if it is ok to do so.
      , interopRequire('babel-plugin-transform-simplify-comparison-operators')

        // react optimisations
      , interopRequire('babel-plugin-transform-react-constant-elements')
      , interopRequire('babel-plugin-transform-react-inline-elements')
      ]
    }
  }
}

==> babel-preset-all-0.0.2.tgz: package/index.js <==

interopRequire = function (name) {
  const req = require(name)
  return name['default'] ? name['default'] : name
}

// export the config
module.exports = {
  presets: [
    interopRequire('babel-preset-es2015')  // enable all es2015 features
  , interopRequire('babel-preset-stage-0') // enable experimental (es2016, es2017) features
  , interopRequire('babel-preset-react')   // enable jsx and flowtype
  ]
, plugins: [
    // add legacy decorator support
    interopRequire('babel-plugin-transform-decorators-legacy')

    // turn on strict mode
  , interopRequire('babel-plugin-transform-strict-mode')

    // transform runtime
  , interopRequire('babel-plugin-transform-runtime')
  ]
, env: {
    development: {
      plugins: [
        // enable simple typechecking
        interopRequire('babel-plugin-typecheck')
      // , [
      //     interopRequire('babel-plugin-react-transform')
      //   , {
      //       transforms: [{
      //         transform: "react-transform-hmr"
      //       , imports:   [ "react" ]
      //       , locals:    [ "module" ]
      //     }]
      //   }]
      ]
    }
  , production: {
      plugins: [
        // turn boolean literals into !0 for true and !1 for false.
        interopRequire('babel-plugin-transform-minify-booleans')

        // ensure that reserved words are quoted in property accesses
        // eg. obj.catch -> obj['catch']
      , interopRequire('babel-plugin-transform-es3-member-expression-literals')
      , interopRequire('babel-plugin-transform-es3-property-literals')

        // turn valid member expression property literals into plain identifiers
        // eg. obj['foo'] -> obj.foo
      , interopRequire('babel-plugin-transform-member-expression-literals')
      , interopRequire('babel-plugin-transform-property-literals')


        // remove debugger statements
      , interopRequire('babel-plugin-transform-remove-debugger')

        // convert === and !== to == and != if it is ok to do so.
      , interopRequire('babel-plugin-transform-simplify-comparison-operators')

        // react optimisations
      , interopRequire('babel-plugin-transform-react-constant-elements')
      , interopRequire('babel-plugin-transform-react-inline-elements')
      ]
    }
  }
}
